# conda-forge-metadata
[![tests](https://github.com/conda-forge/conda-forge-metadata/actions/workflows/tests.yml/badge.svg)](https://github.com/conda-forge/conda-forge-metadata/actions/workflows/tests.yml) [![pre-commit.ci status](https://results.pre-commit.ci/badge/github/conda-forge/conda-forge-metadata/main.svg)](https://results.pre-commit.ci/latest/github/conda-forge/conda-forge-metadata/main)
[![Publish to PyPI](https://github.com/conda-forge/conda-forge-metadata/actions/workflows/pypi.yml/badge.svg)](https://github.com/conda-forge/conda-forge-metadata/actions/workflows/pypi.yml)

programatic access to conda-forge's metadata
